# Datasets

Geomstats comes with a few small standard datasets that do not require to download any file from some external website.

These datasets are useful to quickly illustrate the behavior of geometric operations and learning algorithms implemented in Geomstats.

They are however often too small to be representative of real world machine learning tasks.
